@@ -26,7 +26,8 @@
 const {Cc, Ci, Cu, Cm, Cr} = require("chrome");
 
 const httpObserver = require("http_observer/http_request_observer");
-const narcissusWorker = require("narcissus_parser/narcissus_worker");
+var narcissusWorker = require("narcissus_parser/narcissus_worker")
+    .narcissusWorker;
 const caching = require("http_observer/caching");
 
 const prompt = Cc["@mozilla.org/embedcomp/prompt-service;1"].
