@@ -20,7 +20,8 @@
 
 var {Cc, Ci, Cu, Cm, Cr} = require("chrome");
 
-const narcissusWorker = require("narcissus_parser/narcissus_worker");
+var narcissusWorker = require("narcissus_parser/narcissus_worker")
+    .narcissusWorker;
 
 const nonTrivialModule = require("js_checker/nontrivial_checker");
 const freeChecker = require("js_checker/free_checker");
@@ -46,16 +47,19 @@ var callbackMap = {};
  * 
  */
 var setHashCallback = function(hash, callback, notification) {
-    console.debug("hash is now ", hash);
+    console.debug('setHashCallback', hash);
     if (hash in callbackMap && isDryRun()) {
         // workaround for issue with dryrun after checking box.
         // do nothing.
         callbackMap[hash] = callback;    
     } else if (hash in callbackMap) {
         console.debug("callback", callbackMap[hash]);
-        notification.close();
+        if (notification && typeof notification.close === 'function') {
+            notification.close();
+        }
         throw Error("already being checked.");	
     } else {
+        console.debug('setting callbackMap for', hash, 'to', callback);
         callbackMap[hash] = callback;
     }
     console.debug("callback is type: ", callback.constructor);
@@ -73,19 +77,22 @@ var removeHashCallback = function(hash) {
  * 
  */
 exports.callbackHashResult = function(hash, result) {
+    console.debug('typeof callbackMap function:', typeof callbackMap[hash]);
+    console.debug('for hash', hash);
     try {
         callbackMap[hash](result, hash);
     } catch (x) {
         console.debug('error in jsChecker', x, 'hash:', hash);
         // return tree as false.
         console.debug("Error with", x);
-        if (typeof callbackMap[hash] == 'function') {
+        if (typeof callbackMap[hash] === 'function') {
             callbackMap[hash](false, hash);
         } else {
             console.debug('callbackHashResult Error', x);
         }
     }
     // remove callback after it's been called.
+    console.debug('JsChecker.callbackHashResult: calling removeHashCallback');
     removeHashCallback(hash);
 };
 
@@ -116,6 +123,7 @@ var JsChecker = function() {
 JsChecker.prototype.searchJs = function(jsCode, resultReady, url) {
     var that = this;
     var bugfix = require('html_script_finder/bug_fix').narcissusBugFixLibreJS;
+    console.debug('JsChecker.searchJs for script url:', url);
     this.url = url;
     this.resultReady = resultReady;
     this.jsCode = jsCode;
@@ -130,7 +138,8 @@ JsChecker.prototype.searchJs = function(jsCode, resultReady, url) {
         console.debug("We have it cached indeed!");
         // there is an existing entry for this exact copy
         // of script text.
-        console.debug('this script result is cached', this.hash, isCached.result.type);
+        console.debug('this script result is cached', this.hash,
+                      isCached.result.type);
         console.debug("Return right away");
         // we are not generating a parse tree.
         this.parseTree = {};
@@ -144,21 +153,27 @@ JsChecker.prototype.searchJs = function(jsCode, resultReady, url) {
         return;
     }
 
+    console.debug('url is not cached:', url);
+
     try {
         // no cache, continue.
         this.relationChecker = relationChecker.relationChecker();
         this.freeToken = types.emptyTypeObj();
         this.nontrivialness = types.emptyTypeObj();
 
-        // use this.hash to keep track of comments made by the nontrivial checker code
-        // about why/how the code is found to be nontrivial.
-        this.nonTrivialChecker = nonTrivialModule.nonTrivialChecker(this.hash);
+        // use this.hash to keep track of comments made by the nontrivial
+        // checker code about why/how the code is found to be nontrivial.
+        this.nonTrivialChecker =
+            nonTrivialModule.nonTrivialChecker(this.hash);
 
         // register callback and hash. So that result
         // can be passed.
-        setHashCallback(this.hash, this.handleTree.bind(this), this.notification);
+        setHashCallback(
+            this.hash, this.handleTree.bind(this), this.notification);
 
         // parse using ChromeWorker.
+        console.debug(
+            'JsChecker.searchJs(): starting narcissusWorker.parse()');
         narcissusWorker.parse(this.jsCode, this.hash);
     } catch (x) {
         console.debug('error', x);
@@ -174,7 +189,7 @@ JsChecker.prototype.handleTree = function(tree, errorMessage) {
         // error parsing tree. Just return nonfree nontrivial.
         this.parseTree = {};
         this.parseTree.freeTrivialCheck = types.nontrivialWithComment(
-                'error parsing: ' + errorMessage);
+            'error parsing: ' + errorMessage);
 
         // cache result with hash of script for future checks.
         scriptsCached.addEntry(this.jsCode, this.parseTree.freeTrivialCheck,
@@ -485,8 +500,11 @@ JsChecker.prototype.checkNode = function(n) {
 };
 
 JsChecker.prototype.removeNotification = function() {
-    if (this.notification && this.notification.close) {
-        console.debug("removing", this.shortText);
+    console.debug('JsChecker.removeNotification()');
+    if (this.notification &&
+        typeof this.notification.close === 'function'
+       ) {
+        console.debug('removing', this.shortText);
         // remove notification early on.
         this.notification.close();
         this.notification = null;
