@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2013, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,22 +19,22 @@
  */
 
 exports.patternUtils = {
-  /**
-   * removeNonalpha
-   *
-   * Remove all nonalphanumeric values, except for
-   * < and >, since they are what we use for tokens.
-   *
-   */
-  removeNonalpha: function (str) {
-	  var regex = /[^a-z0-9<>@]+/gi;
-	  return str.replace(regex, '');
-  },
-  removeWhitespace: function (str) {
-	  return str.replace(/[ \t\r\n]+/gmi,"");
-  },
-  replaceTokens: function (str) {
-	  var regex = /<.*?>/gi;
-	  return str.replace(regex, '.*?');
-  }
-};
\ No newline at end of file
+    /**
+     * removeNonalpha
+     *
+     * Remove all nonalphanumeric values, except for
+     * < and >, since they are what we use for tokens.
+     *
+     */
+    removeNonalpha: function (str) {
+	    var regex = /[^a-z0-9<>@]+/gi;
+	    return str.replace(regex, '');
+    },
+    removeWhitespace: function (str) {
+	    return str.replace(/\s+/gmi, '');
+    },
+    replaceTokens: function (str) {
+	    var regex = /<.*?>/gi;
+	    return str.replace(regex, '.*?');
+    }
+};
