@@ -37,7 +37,6 @@ const removedScripts = require("script_entries/removed_scripts").removedScripts;
 const acceptedScripts = require("script_entries/accepted_scripts").acceptedScripts;
 const dryRunScripts = require("script_entries/dryrun_scripts").dryRunScripts;
 const httpObserver = require("http_observer/http_request_observer");
-const narcissusWorker = require("narcissus_parser/narcissus_worker");
 const prefObserver = require("pref_observer/pref_observer");
 
 const types = require("js_checker/constant_types");
@@ -48,9 +47,7 @@ const prefChange = require("addon_management/prefchange");
 prefChange.init();
 
 var allowedRef = require("http_observer/allowed_referrers").allowedReferrers;
-
 var urlHandler = require("url_handler/url_handler");
-
 var widgetIsOn = false;
 
 const librejsStorage = require("settings/storage").librejsStorage;
@@ -58,12 +55,10 @@ const librejsStorage = require("settings/storage").librejsStorage;
 var cachedResult = librejsStorage.init();
 librejsStorage.generateCacheFromDB();
 
-
 var uiInfo = require("ui/ui_info");
 var scriptPanel = require("ui/script_panel.js");
 const removeHashCallback = require("js_checker/js_checker").removeHashCallback;
 var panelContent = function () {
-
     let panel = this;
     var message, externalEntries, 
     externalScripts, urlTabIndex, tabData;
@@ -82,9 +77,7 @@ var panelContent = function () {
                                'urlData': scriptsData,
                                'isAllowed': allowedRef.urlInAllowedReferrers(url)});
 	    }
-        
     });
-
 };
 
 // page mod was here.
@@ -154,9 +147,11 @@ mainPanel.port.on('allowAllClicked', function (url) {
 mainPanel.port.on('disallowAllClicked', function (url) {
     console.debug('url is', url);
     url = urlHandler.removeFragment(url);
-    console.debug('before clear, url is in allowedRef', allowedRef.urlInAllowedReferrers(url));
+    console.debug('before clear, url is in allowedRef',
+                  allowedRef.urlInAllowedReferrers(url));
     allowedRef.clearSinglePageEntry(url);
-    console.debug('after clear, url is in allowedRef', allowedRef.urlInAllowedReferrers(url));
+    console.debug('after clear, url is in allowedRef',
+                  allowedRef.urlInAllowedReferrers(url));
     mainPanel.hide();
     tabs.activeTab.reload(); 
 });
@@ -164,6 +159,7 @@ mainPanel.port.on('disallowAllClicked', function (url) {
 mainPanel.port.on('openInTab', function (text) {
     var str = generateDataURI(text);
     tabs.open(str);
+    mainPanel.hide();
 });
 
 var generateDataURI = function (encodedText) {
@@ -220,4 +216,5 @@ var menuitem = require("menuitems").Menuitem({
 mainPanel.port.on('openSesame', function () {
     // open the settings tab.
     settings_tab.settingsManager.open();
+    mainPanel.hide();
 });
