@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ forget this test for now.
 
 var main = require("main");
 
-var pageMod = require("page-mod");
+var pageMod = require("sdk/page-mod");
 var tabs = require("sdk/tabs");
 var data = require("sdk/self").data;
 
@@ -53,4 +53,4 @@ exports.testFreeLibraryjQuery172 = function (test) {
     tabs.open("http://lduros.net/assets/librejs/tests/free-libraries/");
 
 };
-*/
\ No newline at end of file
+*/
